@@ -79,8 +79,10 @@ class Connection(object):
     def is_alive(self):
         header = Tracker_header()
         header.cmd = FDFS_PROTO_CMD_ACTIVE_TEST
+        header.status = 2
         try:
             header.send_header(self)
+            header.recv_header(self)
             return True
         except:
             return False
@@ -214,4 +216,4 @@ def test_connection_ping():
     from fdfs_client import client
     cli = client.Fdfs_client(client.get_tracker_conf(os.path.expanduser('~/.local/etc/fdfs/client.conf')))
     conn = cli.tracker_pool.get_connection()
-    conn.ping()
+    conn.is_alive()
